Command

Enum Command 

pub enum Command {
    Build {
        all: bool,
        project: Option<String>,
        package: PackageType,
        rpm_opts: RpmOpts,
        flatpak_opts: FlatpakOpts,
        oci_opts: OciOpts,
    },
    Clean,
    List,
    Init {
        path: PathBuf,
        yes: bool,
    },
    Completion {
        shell: Shell,
    },
    CI,
    Update {
        labels: Vec<String>,
        filters: Vec<String>,
        excludes: Vec<String>,
    },
    Run {
        scripts: Vec<String>,
        labels: Option<String>,
    },
}

Variants



Build

Build a project

This is the main entrypoint of Andaman. This command optionally accepts a project name to build, or an --all flag to build all projects in the manifest. If no project name is specified, and the --all flag is not specified, the program will exit with an error.

Fields

all: bool

Builds all projects in the current directory

project: Option<String>

Project to build

package: PackageType

Builds a specific artifact format

rpm_opts: RpmOpts

Options for RPM builds

flatpak_opts: FlatpakOpts

Options for Flatpak builds

oci_opts: OciOpts

Options for OCI builds



Clean

Cleans up the build directory



List

Lists all projects in the manifest



Init

Initializes a new project manifest

Fields

path: PathBuf

Path to the project manifest

yes: bool

Assume yes to all questions



Completion

Generate shell completions

Fields

shell: Shell

Shell to generate completions for



CI

Get CI output for Github Actions



Update

Update all projects

Fields

labels: Vec<String>

Labels to pass to the scripts

filters: Vec<String>

Only run update scripts in project with the specified labels

This should be a comma-separated list of filters. Each time --filters=... is specified, the comma-separated list of key-values will be checked against a project. If missing or different, the project will be ignored. However, specifying --filters multiple times will create an “or” effect — the project will not be ignored if it satisfies one of the list of --filters. For example, -f a=1,b=2 -f c=3 means the project needs to satisfy either “a=1” and “b=2”, or only “c=3”.

excludes: Vec<String>

Exclude update scripts in project with the specified labels

This should be a comma-separated list of excludes. Each time --exclude=... is specified, the comma-separated list of key-values will be checked against the labels of a project, and it will be ignored if all the key-values are present. In addition, specifying --exclude multiple times will create an “or” effect — a project will be excluded if it satisfies one of the list of --filters. For example, -e a=1,b=2 -e c=3 means projects with “a=1” and “b=2” at the same time, or “c=3”, are excluded. Projects with only “a=1” or “b=2” are not excluded.

This will always override --filters.



Run

Run .rhai scripts

Fields

scripts: Vec<String>
labels: Option<String>